TransactionContext

Struct TransactionContext 

pub struct TransactionContext { /* private fields */ }
Loaded transaction shared between runtime and programs.

This context is valid for the entire duration of a transaction being processed.

Implementations

Source

impl TransactionContext

pub fn new<T>( transaction_accounts: Vec<(Pubkey, T)>, rent: Rent, instruction_stack_capacity: usize, instruction_trace_capacity: usize, ) -> TransactionContext
where T: Into<StoredAccount>,

Constructs a new TransactionContext

The transaction_accounts parameter accepts any type that can be converted into StoredAccount, including AccountSharedData for convenience.

pub fn set_remove_accounts_executable_flag_checks(&mut self, enabled: bool)

pub fn add_account(&mut self, account: (Pubkey, StoredAccount))

pub fn deconstruct_without_keys( self, ) -> Result<Vec<StoredAccount>, InstructionError>

Used in mock_process_instruction

pub fn accounts(&self) -> &TransactionAccounts

pub fn touch_fee_payer(&self)

Touch fee payer.

This is required for OCC executor as all transactions are executed in parallel and for sponsored transactions the fee payer may not get touched during execution since it was “touched” by the TransactionBatchProcessor when it deducted the fee.

The fee payer must be explicitly touched if the transaction is executed in the OCC batch so that the scheduler is able to validate and re-execute transactions that in the same batch use the fee payer.

pub fn accounts_rc(&self) -> &Rc<TransactionAccounts>

pub fn account_keys(&self) -> impl Iterator<Item = &Pubkey>

pub fn get_number_of_accounts(&self) -> u16

Returns the total number of accounts loaded in this Transaction

pub fn get_key_of_account_at_index( &self, index_in_transaction: u16, ) -> Result<&Pubkey, InstructionError>

Searches for an account by its key

pub fn get_account_at_index( &self, index_in_transaction: u16, ) -> Result<&RefCell<StoredAccount>, InstructionError>

Searches for an account by its key

pub fn find_index_of_account(&self, pubkey: &Pubkey) -> Option<u16>

Searches for an account by its key

pub fn find_index_of_program_account(&self, pubkey: &Pubkey) -> Option<u16>

Searches for a program account by its key

pub fn get_instruction_trace_capacity(&self) -> usize

Gets the max length of the InstructionContext trace

pub fn get_instruction_trace_length(&self) -> usize

Returns the instruction trace length.

Not counting the last empty InstructionContext which is always pre-reserved for the next instruction. See also get_next_instruction_context().

pub fn get_instruction_context_at_index_in_trace( &self, index_in_trace: usize, ) -> Result<&InstructionContext, InstructionError>

Gets an InstructionContext by its index in the trace

pub fn get_instruction_context_at_index_in_trace_mut( &mut self, index_in_trace: usize, ) -> Result<&mut InstructionContext, InstructionError>

pub fn get_instruction_context_at_nesting_level( &self, nesting_level: usize, ) -> Result<&InstructionContext, InstructionError>

Gets an InstructionContext by its nesting level in the stack

pub fn get_instruction_context_at_nesting_level_mut( &mut self, nesting_level: usize, ) -> Result<&mut InstructionContext, InstructionError>

pub fn get_instruction_stack_capacity(&self) -> usize

Gets the max height of the InstructionContext stack

pub fn get_instruction_context_stack_height(&self) -> usize

Gets instruction stack height, top-level instructions are height rialo_s_sdk::instruction::TRANSACTION_LEVEL_STACK_HEIGHT

pub fn get_current_instruction_context( &self, ) -> Result<&InstructionContext, InstructionError>

Returns the current InstructionContext

pub fn get_current_instruction_context_mut( &mut self, ) -> Result<&mut InstructionContext, InstructionError>

pub fn get_next_instruction_context( &mut self, ) -> Result<&mut InstructionContext, InstructionError>

Returns the InstructionContext to configure for the next invocation.

The last InstructionContext is always empty and pre-reserved for the next instruction.

pub fn push(&mut self) -> Result<(), InstructionError>

Pushes the next InstructionContext

pub fn pop(&mut self) -> Result<(), InstructionError>

Pops the current InstructionContext

pub fn get_return_data(&self) -> (&Pubkey, &[u8])

Gets the return data of the current InstructionContext or any above

pub fn set_return_data( &mut self, program_id: Pubkey, data: Vec<u8>, ) -> Result<(), InstructionError>

Set the return data of the current InstructionContext

pub fn accounts_resize_delta(&self) -> Result<i64, InstructionError>

Returns the accounts resize delta