Structs
- Alloc
Err - BpfAllocator
- Environment
Config - Invoke
Context - Main pipeline from runtime to program execution.
- Serialized
Account Metadata - Stake
Cache Data - Data structure holding the cached stake and validator accounts.
- Stakes
Handle - Handle for builtin programs to access stake cache data and freeze stakes.
- Syscall
Context - Validator
Account - Represents a validator account with its data.
- Validator
Account View - A lightweight representation of validator data for use by builtin programs.