Module invoke_context

Module invoke_context 

Structs

AllocErr
BpfAllocator
EnvironmentConfig
InvokeContext
Main pipeline from runtime to program execution.
SerializedAccountMetadata
StakeCacheData
Data structure holding the cached stake and validator accounts.
StakesHandle
Handle for builtin programs to access stake cache data and freeze stakes.
SyscallContext
ValidatorAccount
Represents a validator account with its data.
ValidatorAccountView
A lightweight representation of validator data for use by builtin programs.

Functions

mock_process_instruction

Type Aliases

BuiltinFunctionWithContext